@@ -49,5 +49,6 @@ class RateOfChange(QCCheckVar):
         feature = ma.absolute(self.features['rate_of_change'])
         flag[np.nonzero(feature > threshold)] = self.flag_bad
         flag[np.nonzero(feature <= threshold)] = self.flag_good
-        flag[ma.getmaskarray(self.data[self.varname])] = 9
+        x = self.data[self.varname]
+        flag[ma.getmaskarray(x) | ~np.isfinite(x)] = 9
         self.flags['rate_of_change'] = flag
